==> appfs-21.02.tar.gz: home/admin/conf/rootfs/pkg/recoverygui/usr/www/cgi-bin/info.php <==
<?php

include_once("/usr/www/include/SQLite2ToSQLite3.php");
include('/usr/fallback/beroConf.php');
include('/usr/www/include/berogui_small.class.php');

function dump_table ($bc, $table) {
	if (!($rows = $bc->get_rows($table))) {
		return('<b>ERROR: ' . $bc->error() . '</b>');
	}

	$ret =	'<table style="margin-right: auto; margin-left: auto; text-align: center;">' . "\n" .
		'<tr><th>Key</th><th>Value</th></tr>' . "\n";
	while ($row = $bc->get_next_row($rows)) {
		if (strlen($row[1]) == 0) {
			continue;
		}
		$ret .= '<tr><td>' . $row[0] . '</td><td>' . $row[1] . '</td></tr>' . "\n";
	}
	$ret .= '</table>' . "\n";

	return($ret);
}

function display_command ($cmd) {

	exec($cmd, $output, $retval);

	$ret =	'<div style="font-family: monospace;">' . "\n" .
		'<h4># ' . $cmd . '</h4>' . "\n";
	foreach ($output as $line) {
		$ret .= str_replace(' ', '&nbsp;', $line) . "<br />\n";
	}

	$ret .= '</div>' . "\n";

	return($ret);
}

$bc = new beroConf('root');
require_once('/usr/www/include/redirect.php');

$gui = new berogui_small('beroNet VoIP Gateway: Information');

$cmdlist = array('/sbin/ifconfig -a', '/bin/mount', '/bin/df -h', '/bin/cat /proc/meminfo');

echo	$gui->header() .
	'<h3>UUID of this beroNet VoIP Gateway</h3>' . "\n" .
	'<div style="text-align: center;">' . trim(file_get_contents('/sys/class/beronet/gateway/serial')) . '</div>' . "\n" .
	'<h3>Contents of table \'root\'</h3>' . "\n" .
	dump_table($bc, 'root') .
	'<h3>Commandline-Tools</h3>' . "\n";

foreach ($cmdlist as $cmd) {
	echo display_command($cmd);
}

echo	'<h3>Other Information</h3>' . "\n" .
	'<ul><li><a href="/cgi-bin/phpinfo.php" target="_blank">PHPinfo</a></li></ul>' . "\n" .
	$gui->footer('info');
?>

==> appfs-24.01.01.tar.gz: home/admin/conf/rootfs/pkg/recoverygui/usr/www/cgi-bin/info.php <==
<?php

include_once("/usr/www/include/SQLite2ToSQLite3.php");
include('/usr/fallback/beroConf.php');
include('/usr/www/include/berogui_small.class.php');

function dump_table ($bc, $table) {
	if (!($rows = $bc->get_rows($table))) {
		return('<b>ERROR: ' . $bc->error() . '</b>');
	}

	$ret =	'<table style="margin-right: auto; margin-left: auto; text-align: center;">' . "\n" .
		'<tr><th>Key</th><th>Value</th></tr>' . "\n";
	while ($row = $bc->get_next_row($rows)) {
		if (strlen($row[1]) == 0) {
			continue;
		}
		$ret .= '<tr><td>' . $row[0] . '</td><td>' . $row[1] . '</td></tr>' . "\n";
	}
	$ret .= '</table>' . "\n";

	return($ret);
}

function display_command ($cmd) {

	exec($cmd, $output, $retval);

	$ret =	'<div style="font-family: monospace;">' . "\n" .
		'<h4># ' . $cmd . '</h4>' . "\n";
	foreach ($output as $line) {
		$ret .= str_replace(' ', '&nbsp;', $line) . "<br />\n";
	}

	$ret .= '</div>' . "\n";

	return($ret);
}

$bc = new beroConf('root');
require_once('/usr/www/include/redirect.php');

$gui = new berogui_small('beroNet SBC / VoIP Gateway: Information');

$cmdlist = array('/sbin/ifconfig -a', '/bin/mount', '/bin/df -h', '/bin/cat /proc/meminfo');

echo	$gui->header() .
	'<h3>Serialnumber of this beroNet Device</h3>' . "\n" .
	'<div style="text-align: center;">' . trim(file_get_contents('/sys/class/beronet/gateway/serial')) . '</div>' . "\n" .
	'<h3>Contents of table \'root\'</h3>' . "\n" .
	dump_table($bc, 'root') .
	'<h3>Commandline-Tools</h3>' . "\n";

foreach ($cmdlist as $cmd) {
	echo display_command($cmd);
}

echo	'<h3>Other Information</h3>' . "\n" .
	'<ul><li><a href="/cgi-bin/phpinfo.php" target="_blank">PHPinfo</a></li></ul>' . "\n" .
	$gui->footer('info');
?>
